@@ -6,12 +6,13 @@ try:
 except ImportError:
     _have_numpy = False
 
-from .distob import (scatter, gather, vectorize, apply, call_all, 
-                     Remote, proxy_methods, ObjectHub, ObjectEngine, Ref)
+from .distob import (scatter, gather, vectorize, apply, call_all,
+                     Remote, proxy_methods, ObjectHub, ObjectEngine, Id, Ref,
+                     call, methodcall, convert_result)
 
 engine = None
 
-__version__ = '0.1.5'
+__version__ = '0.2.0'
 
 if _have_numpy:
     from .arrays import (RemoteArray, DistArray, transpose, rollaxis,
